@@ -6,7 +6,7 @@ from time import time
 from typing import Any
 
 from .const import VERSION, VERSION_APP
-from .exception_classes import ErrorMSG, LoginError, NoAdminError
+from .exception_classes import Error, ErrorMSG, LoginError, NoAdminError, PhoneOrEmailFail
 from .gql_handler import GQLHandler
 from .model import Chats, ChatsNew, SimpleChat
 from .pyxplora import PyXplora
@@ -47,6 +47,14 @@ class PyXploraApi(PyXplora):
                     signup,
                 )
                 if self._gqlHandler:
+                    if not self._gqlHandler.checkEmailOrPhoneExist(
+                        UserContactType.EMAIL if self._email else UserContactType.PHONE,
+                        email=self._email,
+                        countryCode=self._countrycode,
+                        phoneNumber=self._phoneNumber,
+                    ):
+                        self.error_message = ErrorMSG.PHONE_MAIL_ERR.value
+                        raise PhoneOrEmailFail()
                     retryCounter = 0
                     while not self._isConnected() and (retryCounter < self.maxRetries + 2):
                         retryCounter += 1
@@ -55,8 +63,9 @@ class PyXploraApi(PyXplora):
                         try:
                             self._issueToken = self._gqlHandler.login()
                         except LoginError as error:
-                            self.error_message = error.message
-                        except Exception:
+                            self.error_message = error.error_message
+                            retryCounter = self.maxRetries + 2
+                        except Error:
                             if retryCounter == self.maxRetries + 2:
                                 self.error_message = ErrorMSG.SERVER_ERR
                             else:
@@ -69,7 +78,7 @@ class PyXploraApi(PyXplora):
                         self.dtIssueToken = int(time())
                 else:
                     raise Exception("Unknown error creating a new GraphQL handler instance.")
-            except Exception:
+            except Error:
                 # Login failed.
                 self._logoff()
         return self._issueToken
@@ -91,7 +100,7 @@ class PyXploraApi(PyXplora):
         return
 
     def version(self) -> str:
-        return "{0}-{1}".format(VERSION, VERSION_APP)
+        return f"{VERSION}-{VERSION_APP}"
 
     def setDevices(self, ids: list = []) -> list[str]:
         return self._setDevices(ids)
@@ -165,7 +174,7 @@ class PyXploraApi(PyXplora):
                             "xcoin": xcoin,
                         }
                     )
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = contacts
             if not dataOk:
@@ -197,7 +206,7 @@ class PyXploraApi(PyXplora):
                             "status": alarm["status"],
                         }
                     )
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = alarms
             if not dataOk:
@@ -255,7 +264,7 @@ class PyXploraApi(PyXplora):
                     "watch_charging": _watch_charging,
                     "watch_last_location": _watchLastLocate,
                 }
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = watch_location
             if not dataOk:
@@ -286,7 +295,7 @@ class PyXploraApi(PyXplora):
                     asktrack_raw = WatchOnlineStatus.ONLINE
                 else:
                     asktrack_raw = WatchOnlineStatus.OFFLINE
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = asktrack_raw
             if dataOk is WatchOnlineStatus.UNKNOWN:
@@ -327,7 +336,7 @@ class PyXploraApi(PyXplora):
                             "create": datetime.fromtimestamp(chat.create).strftime("%Y-%m-%d %H:%M:%S"),
                         }
                     )
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = chats
             if not dataOk:
@@ -343,7 +352,7 @@ class PyXploraApi(PyXplora):
             retryCounter += 1
             try:
                 _chatsNew = self._gqlHandler.chats(wuid, offset, limit, msgId)
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = _chatsNew
             if not dataOk:
@@ -406,7 +415,7 @@ class PyXploraApi(PyXplora):
                             "address": safeZone["address"],
                         }
                     )
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = safe_zones
             if not dataOk:
@@ -445,7 +454,7 @@ class PyXploraApi(PyXplora):
                             "status": silentTime["status"],
                         }
                     )
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = school_silent_mode
             if not dataOk:
@@ -465,7 +474,7 @@ class PyXploraApi(PyXplora):
                 if not _setEnableSilentTime:
                     return bool(_raw)
                 _raw = _setEnableSilentTime
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
@@ -485,7 +494,7 @@ class PyXploraApi(PyXplora):
                 if not _setEnableSilentTime:
                     return bool(_raw)
                 _raw = _setEnableSilentTime
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
@@ -517,7 +526,7 @@ class PyXploraApi(PyXplora):
                 if not _modifyAlarm:
                     return bool(_raw)
                 _raw = _modifyAlarm
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
@@ -537,7 +546,7 @@ class PyXploraApi(PyXplora):
                 if not _modifyAlarm:
                     return bool(_raw)
                 _raw = _modifyAlarm
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = _raw
             if not dataOk:
@@ -603,7 +612,7 @@ class PyXploraApi(PyXplora):
                         "qrCode": watch["qrCode"],
                         "model": watch["groupName"],
                     }
-            except Exception as error:
+            except Error as error:
                 _LOGGER.debug(error)
             dataOk = watches
             if not dataOk:
@@ -621,7 +630,7 @@ class PyXploraApi(PyXplora):
         qrCode: str = wqr.get("qrCode", "=")
         try:
             return self._gqlHandler.getWatchState(qrCode=qrCode.split("=")[1])
-        except Exception as error:
+        except Error as error:
             _LOGGER.debug(error)
             return {}
 
